// ignore_for_file: use_build_context_synchronously

import 'dart:async';
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/mobile_pos_platform_interface.dart';
import 'package:mobile_pos/mobile_pos_sdk.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/helpers/logger.dart';
import 'package:mobile_pos/src/models/raven_const.dart';
import 'package:mobile_pos/src/network/api_requests.dart';
import 'package:mobile_pos/src/shared_widgets/raven_money_text.dart';
import 'package:mobile_pos/src/shared_widgets/raven_pay_card_pin_widget.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/shared_widgets/powerby_by_raven_widget.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_close_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_pin_widget.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_scaffold.dart';

class CardPin extends StatefulWidget {
  final double amount;
  final PaymentType paymentType;
  final String deviceName;
  const CardPin(
      {super.key,
      required this.amount,
      required this.deviceName,
      required this.paymentType});

  @override
  State<CardPin> createState() => _CardPinState();
}

class _CardPinState extends State<CardPin> {
  StreamSubscription? streamSubscription;

  final _pinController = TextEditingController();
  bool isLoading = false;
  @override
  void initState() {
    super.initState();
    streamSubscription = MobilePosPlatform
        .instance.channelStreamController!.stream
        .listen((event) async {
      if (event.eventType == RavenMPosEventType.pin) {
        isLoading = false;
        setAppState();
        if (mounted) {
          showSnack(context, "incorrect PIN.. please try again");
        }
      }
      if (event.eventType == RavenMPosEventType.transactionError) {
        streamSubscription!.cancel();

        if (mounted) {
          Navigator.pop(context);
          showSnack(context, "${event.data}... please try again");
        }
        streamSubscription!.cancel();
        MobilePosPlatform.instance.disconnectDevice();
      }
      if (event.eventType == RavenMPosEventType.disconnected) {
        if (mounted) {
          Navigator.pop(context);
          showSnack(context, "device disconnected... please try again");
        }

        return;
      }
      if (event.eventType == RavenMPosEventType.processPayment) {
        if (mounted) {
          isLoading = false;
          setAppState();
          streamSubscription!.cancel();
          MobilePosPlatform.instance.disconnectDevice();
          if (event.data != null) {
            logData(event.data);
            if (widget.paymentType == PaymentType.card) {
              await ApiRequests.processCard(
                  context, widget.amount, event.data ?? '');
            }
            if (widget.paymentType == PaymentType.checkBalance) {
              await ApiRequests.getCardBalance(context, event.data ?? '');
            }
          } else {
            pluginConfig.onError.call(
                BankBoxException(code: kNibbsError, message: 'Payment failed'));
          }
        }
      }
    });
  }

  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;
    return WillPopScope(
      onWillPop: () async {
        MobilePosPlatform.instance.cancelOnPinEntry();
        MobilePosPlatform.instance.disconnectDevice();
        return true;
      },
      child: RavenPayScaffold(
        body: Column(
          children: [
            Padding(
              padding:
                  EdgeInsets.symmetric(horizontal: kHoriontalScreenPadding),
              child: Column(
                mainAxisSize: MainAxisSize.min,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  const Gap(24),
                  Row(
                    children: [
                      RavenPayCloseButton(
                        isArrow: true,
                        text: "",
                        onBackPressed: () {
                          MobilePosPlatform.instance.cancelOnPinEntry();
                          MobilePosPlatform.instance.disconnectDevice();
                          Navigator.pop(context);
                        },
                      ),
                      const Spacer(),
                    ],
                  ),
                  const Gap(24),
                  Align(
                      alignment: Alignment.centerLeft,
                      child: RavenPayText.heading(
                        "Card PIN",
                        fontSize: 20,
                      )),
                  const Gap(12),
                  RichText(
                      text: TextSpan(
                          text:
                              "Give the user your device to enter their  Card PIN",
                          style: subtitle2.copyWith(fontSize: 14),
                          children: const [])),
                  const Gap(34),
                  SizedBox(
                    width: 120,
                    height: 50,
                    child: RavenPayPinWidget(
                      pinController: _pinController,
                    ),
                  )
                ],
              ),
            ),
            Gap(size.height * 0.08),
            Container(
                padding: const EdgeInsets.symmetric(horizontal: 20),
                height: 60,
                width: double.infinity,
                decoration: BoxDecoration(
                    border: Border.all(
                        color: const Color(0xffDADADA).withOpacity(0.31))),
                child: Row(
                  children: [
                    Expanded(
                      child: Column(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          mainAxisAlignment: MainAxisAlignment.center,
                          children: [
                            Text("Payment To", style: subtitle2),
                            const Gap(6),
                            Text(widget.deviceName,
                                overflow: TextOverflow.ellipsis,
                                style: headling1.copyWith(fontSize: 14))
                          ]),
                    ),
                    const Gap(34),
                    if (widget.paymentType == PaymentType.card) ...[
                      Container(
                        padding: const EdgeInsets.symmetric(
                            horizontal: 12, vertical: 8),
                        decoration: BoxDecoration(
                            color: AppColors.lightOragen,
                            borderRadius: BorderRadius.circular(24)),
                        child: RavenPayMoneyWidget(
                          amount: widget.amount.toString(),
                          color: AppColors.ravenOrageColor,
                        ),
                      )
                    ]
                  ],
                )),
            RavenPayCardPinWidget(
                length: 4,
                randomizeKeys: true,
                onChange: (val) {
                  _pinController.text = val;
                  setAppState();
                },
                amount: _pinController.text),
            const Gap(8),
            Padding(
              padding:
                  EdgeInsets.symmetric(horizontal: kHoriontalScreenPadding),
              child: RavenPayButton(
                enabled: _pinController.text.length == 4,
                buttonText: "Proceed",
                busy: isLoading,
                onPressed: () {
                  isLoading = true;
                  setAppState();
                  MobilePosPlatform.instance.onPinRequest(_pinController.text);
                },
              ),
            ),
            const Gap(16),
            PoweredByRaven(
              paddingBottom: Platform.isAndroid ? 16 : 0,
              fontSize: 9,
            ),
          ],
        ),
      ),
    );
  }

  void setAppState() {
    if (mounted) {
      setState(() {});
    }
  }
}
