import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/models/network_stability_model.dart';
import 'package:mobile_pos/src/network/api_requests.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet_capsule.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button_loader.dart';
import 'package:mobile_pos/src/shared_widgets/stability_drop_down.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';

class NetworkStatusSheet extends StatefulWidget {
  const NetworkStatusSheet({super.key});

  @override
  State<NetworkStatusSheet> createState() => _NetworkStatusSheetState();
}

class _NetworkStatusSheetState extends State<NetworkStatusSheet> {
  List<dynamic> networkStats = [];
  var currentFilterType = FilterType.ten;
  int currentIndex = 0;
  @override
  void initState() {
    getNetworkStatsData();
    super.initState();
  }

  getNetworkStatsData() async {
    var response = await ApiRequests.getNetworkStates();
    if (response.runtimeType == bool) {
      return;
    }
    networkStats =
        (response).map((e) => NetworkStabilityModel.fromJson(e)).toList();
    if (mounted) {
      setState(() {});
    }
  }

  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;

    return Container(
      color: Colors.white,
      height: size.height * 0.85,
      padding: EdgeInsets.symmetric(horizontal: kHoriontalScreenPadding),
      child: Column(
        children: [
          const Gap(12),
          const RavenPayBottomSheetCapsule(),
          const Gap(24),
          Row(
            children: [
              Expanded(
                child: Text("Network Status",
                    style: headling1.copyWith(fontSize: 20)),
              ),
              GestureDetector(
                onTap: () {
                  Navigator.pop(context);
                },
                child: Container(
                    height: 32,
                    width: 32,
                    padding: const EdgeInsets.all(8),
                    decoration: BoxDecoration(
                        color: AppColors.ravenLightGrey4,
                        shape: BoxShape.circle),
                    child: Image.asset(loadAsset("close_icon.png"))),
              ),
            ],
          ),
          const Gap(8),
          const Divider(),
          const Gap(16),
          Row(
            children: [
              StabilityDropDown(
                  onChange: (val) {
                    currentFilterType = val;
                    if (val == FilterType.ten) {
                      currentIndex = 0;
                    }
                    if (val == FilterType.thirty) {
                      currentIndex = 1;
                    }
                    if (val == FilterType.hour) {
                      currentIndex = 2;
                    }
                    setState(() {});
                  },
                  currentValue: currentFilterType),
              Expanded(
                child: Align(
                  alignment: Alignment.centerRight,
                  child: FittedBox(
                    fit: BoxFit.scaleDown,
                    child: Row(
                        mainAxisAlignment: MainAxisAlignment.end,
                        children: [
                          IndicatorItem(
                            name: "Good",
                            color: AppColors.ravenSuccessColor,
                          ),
                          IndicatorItem(
                            name: "Fair",
                            color: AppColors.ravenOrageColor,
                          ),
                          IndicatorItem(
                            name: "Poor",
                            color: AppColors.ravenRed,
                          )
                        ]),
                  ),
                ),
              )
            ],
          ),
          const Gap(20),
          if (networkStats.isEmpty) ...[
            Expanded(
              child: Center(
                child: RavenButtonLoader(
                    size: 28, color: pluginConfig.theme!.primaryColor),
              ),
            )
          ] else ...[
            Expanded(
              child: SingleChildScrollView(
                child: Table(
                    border: TableBorder.all(
                        borderRadius: BorderRadius.circular(12),
                        color: AppColors.ravenPayGrey2.withOpacity(0.5)),
                    columnWidths: const {
                      0: FlexColumnWidth(3),
                      1: FlexColumnWidth(2),
                      2: FlexColumnWidth(2),
                      3: FlexColumnWidth(2),
                    },
                    children: [
                      _tableHeader(),
                      ...networkStats[currentIndex]
                          .banks
                          .map(
                            (e) => _tablebody(e),
                          )
                          .toList()
                    ]),
              ),
            ),
          ],
          const Gap(16)
        ],
      ),
    );
  }

  TableRow _tableHeader() {
    return TableRow(
        decoration: const BoxDecoration(
          color: Colors.transparent,
        ),
        children: [
          tableHeaderItem("Bank"),
          tableHeaderItem("Master"),
          tableHeaderItem("Visa"),
          tableHeaderItem("Verve"),
        ]);
  }

  Widget tableHeaderItem(String name) {
    return Container(
      alignment: Alignment.centerLeft,
      margin: const EdgeInsets.only(left: 8.0),
      padding: const EdgeInsets.symmetric(horizontal: 8.0, vertical: 18),
      child: FittedBox(
        fit: BoxFit.scaleDown,
        child: Text(
          name,
          style: TextStyle(
              color: AppColors.ravenDark, fontWeight: FontWeight.w700),
        ),
      ),
    );
  }

  TableRow _tablebody(BankData bankData) {
    return TableRow(decoration: const BoxDecoration(), children: [
      Container(
        margin: EdgeInsets.zero,
        color: Colors.transparent,
        padding: const EdgeInsets.symmetric(horizontal: 24, vertical: 18),
        child: Text(
          bankData.bank.capitalize(),
          style: TextStyle(
              fontSize: 12,
              color: AppColors.ravenDark,
              fontWeight: FontWeight.w500),
        ),
      ),
      Padding(
        padding: const EdgeInsets.symmetric(horizontal: 8.0, vertical: 18),
        child: Text(getValue(getPercent(bankData, "mastercard")),
            style: subtitle.copyWith(
                fontSize: 12,
                color: getStyle(getPercent(bankData, "mastercard")).color)),
      ),
      Padding(
        padding: const EdgeInsets.symmetric(horizontal: 8.0, vertical: 18),
        child: Text(getValue(getPercent(bankData, "visa")),
            style: subtitle.copyWith(
                fontSize: 12,
                color: getStyle(getPercent(bankData, "visa")).color)),
      ),
      Padding(
          padding: const EdgeInsets.symmetric(horizontal: 8.0, vertical: 18),
          child: Text(getValue(getPercent(bankData, "verve")),
              style: subtitle.copyWith(
                  fontSize: 12,
                  color: getStyle(getPercent(bankData, "verve")).color)))
    ]);
  }

  TextStyle getStyle(double percent) {
    return TextStyle(
        color: percent == -1
            ? AppColors.ravenPayGrey
            : percent < 50
                ? AppColors.ravenRed
                : percent < 75
                    ? AppColors.ravenOrageColor
                    : AppColors.ravenSuccessColor,
        fontWeight: FontWeight.w500);
  }

  String getValue(double value) {
    if (value == -1) {
      return "N/A";
    }
    return "$value%";
  }

  double getPercent(BankData bank, String brand) {
    try {
      var data = bank.brands.firstWhere(
          (element) => element.brand.toUpperCase() == brand.toUpperCase());
      return double.tryParse(data.percentage.toDouble().toStringAsFixed(1)) ??
          -1;
    } catch (ex) {
      return -1;
    }
  }
}

class IndicatorItem extends StatelessWidget {
  final String name;
  final Color color;
  const IndicatorItem({super.key, required this.color, required this.name});

  @override
  Widget build(BuildContext context) {
    return Container(
      margin: const EdgeInsets.only(left: 14),
      child: Row(
        children: [
          Container(
            height: 8,
            width: 8,
            decoration: BoxDecoration(shape: BoxShape.circle, color: color),
          ),
          const Gap(4),
          Text(name,
              style:
                  subtitle2.copyWith(color: AppColors.ravenDark, fontSize: 14))
        ],
      ),
    );
  }
}
