import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/models/terminal_model.dart';
import 'package:mobile_pos/src/shared_widgets/raven_money_text.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/request_pos/terminal_info_screen.dart';

class BankBoxTerminalItemWidget extends StatelessWidget {
  final TerminalModel terminal;
  const BankBoxTerminalItemWidget({super.key, required this.terminal});

  @override
  Widget build(BuildContext context) {
    return InkWell(
      splashColor: Colors.transparent,
      highlightColor: Colors.transparent,
      onTap: () {
        pushRoute(
            context,
            TerminalInfoScreen(
              model: terminal,
            ));
      },
      child: Container(
          margin: const EdgeInsets.symmetric(vertical: 8),
          padding: const EdgeInsets.symmetric(horizontal: 12, vertical: 16),
          width: double.infinity,
          decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(16),
              color: Colors.white,
              boxShadow: const [
                BoxShadow(
                    color: Color(0xFFE9E9E9), spreadRadius: 1, blurRadius: 14)
              ]),
          child: Column(
            children: [
              Row(
                children: [
                  Container(
                      height: 40,
                      width: 40,
                      padding: const EdgeInsets.only(top: 8),
                      decoration: BoxDecoration(
                          color: AppColors.ravenGrey4.withOpacity(0.5),
                          shape: BoxShape.circle),
                      child: Image.asset(loadAsset("bankbox_icon.png"))),
                  const Gap(12),
                  Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      Hero(
                        tag: terminal.tid ?? "",
                        child: Text((terminal.tidLabel ?? "").toUpperCase(),
                            style: headling1.copyWith(
                                fontSize: 16, fontWeight: FontWeight.w800)),
                      ),
                      const Gap(2),
                      Text("Serial: ${terminal.serial ?? ""}",
                          style: subtitle.copyWith(
                              fontWeight: FontWeight.w600,
                              fontSize: 12,
                              color: AppColors.ravenGreyLight1))
                    ],
                  )
                ],
              ),
              const Gap(12),
              Container(
                padding:
                    const EdgeInsets.symmetric(horizontal: 12, vertical: 12),
                decoration: BoxDecoration(
                    borderRadius: BorderRadius.circular(6),
                    color: AppColors.ravenGrey4.withOpacity(0.4)),
                child: const Row(children: [
                  ItemWidget(
                    name: "CASH IN",
                    value: 0.0,
                  ),
                ]),
              )
            ],
          )),
    );
  }
}

class ItemWidget extends StatelessWidget {
  final String name;
  final double value;
  const ItemWidget({super.key, required this.name, required this.value});

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Text(name,
            style: subtitle.copyWith(
                fontWeight: FontWeight.w600,
                fontSize: 12,
                color: AppColors.lightTextColor)),
        const Gap(2),
        RavenPayMoneyWidget(
          amount: value.toString(),
          fontSize: 16,
        )
      ],
    );
  }
}
