import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';

class RequestPosListItem2 extends StatelessWidget {
  final Widget item;
  const RequestPosListItem2({
    required this.item,
    super.key,
  });

  @override
  Widget build(BuildContext context) {
    return Row(
      children: [
        const Icon(Icons.info, color: Colors.white, size: 18),
        const Gap(8),
        Expanded(
            child: Align(
                alignment: Alignment.centerLeft,
                child: FittedBox(fit: BoxFit.scaleDown, child: item))),
      ],
    );
  }
}

class RequestPostItem extends StatelessWidget {
  final String title;
  final Widget? widget;
  const RequestPostItem({super.key, required this.title, this.widget});

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.symmetric(vertical: 8),
      child: Row(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Container(
              height: 20,
              width: 20,
              decoration: BoxDecoration(
                  color: AppColors.darkGrey.withOpacity(0.06),
                  shape: BoxShape.circle),
              child: Icon(Icons.check, size: 12, color: AppColors.darkGrey)),
          const Gap(12),
          if (widget == null) ...[
            Expanded(
                child: Text(title,
                    style: bodyText.copyWith(
                        fontWeight: FontWeight.w500,
                        fontSize: 12,
                        color: AppColors.darkGrey)))
          ] else ...[
            widget!
          ]
        ],
      ),
    );
  }
}

class SelectedIndicator extends StatelessWidget {
  final int currentIndex;
  final Function(int) onTap;
  const SelectedIndicator(
      {super.key, required this.currentIndex, required this.onTap});

  @override
  Widget build(BuildContext context) {
    return Container(
        padding: const EdgeInsets.symmetric(horizontal: 10, vertical: 10),
        decoration: BoxDecoration(
            color: pluginTheme.onPrimary.withOpacity(0.2),
            borderRadius: BorderRadius.circular(24)),
        child: Row(
          mainAxisSize: MainAxisSize.min,
          children: [
            const Gap(12),
            item(0, currentIndex, onTap),
            const Gap(12),
          ],
        ));
  }

  Widget item(int index, int currentIndex, Function(int) onTap) {
    return GestureDetector(
      onTap: () => onTap(index),
      child: Container(
        height: 10,
        width: 10,
        decoration: BoxDecoration(
            shape: BoxShape.circle,
            color: index == currentIndex
                ? pluginTheme.onPrimary
                : pluginTheme.onPrimary.withOpacity(0.2)),
      ),
    );
  }
}
